##  Activating a Report
After you've downloaded a report from the SAP LeanIX Store, it's added to your workspace, but it doesn't automatically appear on the Reports page. This means that the report is not available to non-admin workspace users.
To activate a report, follow these steps:
  1. In the administration area, go to the Reports section.
  2. For the report that you want to activate, click Show report (eye icon).
![Selecting the](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b75ee7a441014a67fe6cf88f2c408_LowRes.png)
Activating a Report Downloaded from the SAP LeanIX Store


The report gets added to the Reports page and becomes available to non-admin workspace users.
You can manage custom reports in the Reports section of the administration area. If needed, you can delete or deactivate (hide) custom reports. Hiding a report removes it from the Reports page.
YesNo
Send
